@@ -1,10 +1,15 @@
+-- |
+-- Module: Data.Conduit.Codec.Base32
+-- Copyright: (c) 2014 Magnus Therning
+-- License: BSD3
 module Data.Conduit.Codec.Base32 where
 
 import qualified Codec.Binary.Base32 as B32
 import qualified Data.Conduit.Codec.Util as U
 
-import Data.Conduit (Conduit, MonadThrow)
+import Control.Monad.Catch (MonadThrow)
 import Data.ByteString (ByteString, empty)
+import Data.Conduit (Conduit)
 
 encode :: (Monad m) => Conduit ByteString m ByteString
 encode = U.encodeI B32.b32_encode_part B32.b32_encode_final empty
