@@ -9,13 +9,13 @@ import qualified Codec.Binary.Uu as Uu
 
 import qualified Data.ByteString as BS
 import qualified Data.ByteString.Char8 as BSC
-import Test.HUnit
-import Test.Framework (Test)
-import Test.Framework.TH
-import Test.Framework.Providers.HUnit
-import Test.Framework.Providers.QuickCheck2
 import Data.Word (Word8)
 
+import Test.Tasty
+import Test.Tasty.TH
+import Test.Tasty.HUnit
+import Test.Tasty.QuickCheck
+
 case_enc_foobar :: IO ()
 case_enc_foobar = do
     BS.empty            @=? Uu.encode BS.empty
@@ -39,5 +39,5 @@ case_dec_foobar = do
 prop_encdec :: [Word8] -> Bool
 prop_encdec ws = (BS.pack ws) == (fromRight $ Uu.decode $ Uu.encode $ BS.pack ws)
 
-tests :: Test.Framework.Test
+tests :: TestTree
 tests = $(testGroupGenerator)
